==> GeneticsBase_1.0.0.tar.gz: GeneticsBase/R/readGenes.ped.R <==
# $Id: readGenes.ped.R 586 2006-01-17 14:40:50Z weiliang_qiu $

## read .ped file
readGenes.ped <- function(
                          filename, 
                          columns=c("family", "pid", "father", "mother", "sex"), 
                          phase=list(FALSE), 
                          quiet=FALSE, 
                          missingval=c(0), 
                          ...
                          )
{
  ## pedigree file format
  ## --------------------
  ##
  ## line 1         : list of genetic markers
  ## line 2 to (N+1): <family> <pid> <father> <mother> <sex> [<affected>] 
  ##                  <genotype_1> ... <genotype_n>
  ##
  ## some pedigree files contain <affected> after <sex> and before
  ## <genotype_1>, some pedigree files do not.
  ##
  ## <family> is a unique identifier for each family, and within each family
  ## <pid> is a unique identifier for an individual.
  ## <father> and <mother> identify the individuals father and mother
  ##    (if this line refers to a founder, these should be set to
  ##     zero).
  ##  <sex> denotes the individuals sex, using the convention
  ##     1=male, 2=female.
  ##
  ## Each <genotype> is encoded as two integer allele numbers.

  filename=as.character(filename)

  len <- length(columns)

  ## read numer of rows, columns and markers
  res <- .C(
            "getDimOfFile", 
            filename=filename, 
            nrow=as.integer(0), 
            sampleInfoLen=as.integer(len), 
            nmarker=as.integer(0), 
            errorFlag=as.integer(0),
            PACKAGE="GeneticsBase"             
            )

  errorFlag=res$errorFlag
  if(errorFlag!=0)
    stop("Unable to determine file dimensions for ped file `", file, "'.")

  nrow=res$nrow
  if(nrow==0)
    stop("No data in ped file `", file, "'.")

  nmarker=res$nmarker
  if(nmarker==0)
    stop("No marker information in ped file `", file, "'.")

  if(quiet==FALSE)
    cat("Reading", nmarker, "markers and", nrow,
        "subjects from `", filename, "' ...\n") 

  ncol <- 2*nmarker+length(columns)

  ped <- rep(0, nrow*ncol)
  strSpace <- paste(rep(" ", 60), collapse='')
  markerNames <- rep(strSpace, nmarker)

  res.getPed <- .C(
                   "getPed", 
                   filename=filename, 
                   ped=as.integer(ped), 
                   nrow=as.integer(nrow), 
                   ncol=as.integer(ncol), 
                   nmarker=as.integer(nmarker), 
                   markerNames=as.character(markerNames), 
                   errorFlag=as.integer(0),
                   PACKAGE="GeneticsBase"             
                   )

  errorFlag=res.getPed$errorFlag
  if(errorFlag!=0)
    stop("Unable to load data from `", filename, "'")

  ped <- res.getPed$ped
  ped <- matrix(ped, nrow=nrow, byrow=T)
  markerNames <- res.getPed$markerNames
  nmarker <- length(markerNames)

  markercols <- c(
                  sapply(markerNames, 
                         function(x) paste(x, c("1", "2"), sep=".")
                         )
                  )
  ## Add these to the other columns
  colNames <- c(columns, markercols)

  ped <- matrix(ped, nrow=nrow, ncol=ncol) 
  colnames(ped) <- colNames
  rownames(ped) <- paste(ped[, 1], ped[, 2], sep=".")

  ## we can do checking in analysis
  #tmp <- checkColumn(ped, columns)


  ## obtain unique nuclear family id
  family <- as.vector(ped[, 1])
  family.u <- unique(family)

  ## obtain sizes (number of members) of nuclear families
  familySize <- tapply(family, family, length)

  ## obtain the number of nuclear families
  nFamily <- length(family.u)

 if(!quiet)
    cat("generating 'geneSet' object...\n")
  
  cs <- ped2geneSet(ped, markerNames, columns, quiet, filename=filename)

  missingCodes <- lapply(cs@transTables,
                         function(...) as.character(missingval))

  cs@missingCodes <- missingCodes
  cs@notes <- paste("Loaded from file `", filename, "'.", sep='')
  cs@phase <- phase

  if(!quiet)
  { 
    cat("Successfully read the pedigree file `", filename, "'.\n");
    cat("\n")
    cat("Number of Markers: ", length(markerNames), "\n")
    cat("Number of Subjects:", nrow(ped), "\n")
    cat("Number of Families:", nFamily, "\n")
    cat("\n")
  }

  cs
}

## Variants
readGenes.hapmap.ped <- function(filename, ... )
  readGenes.ped(
                filename=filename, 
                columns=c("family", "pid", "father", "mother",
                          "sex", "affected"), 
                ...
                )

readGenes.pbat.ped <- readGenes.hapmap.ped
readGenes.fbat.ped <- readGenes.hapmap.ped

==> GeneticsBase_1.14.0.tar.gz: GeneticsBase/R/readGenes.ped.R <==
# $Id: readGenes.ped.R 1235 2007-06-10 20:01:13Z weiliang_qiu $

## read .ped file
readGenes.ped <- function(
                          filename, 
                          columns=c("family", "pid", "father", "mother", "sex"), 
                          phase=list(FALSE), 
                          quiet=FALSE, 
                          missingval=c(0), 
                          ...
                          )
{
  ## pedigree file format
  ## --------------------
  ##
  ## line 1         : list of genetic markers
  ## line 2 to (N+1): <family> <pid> <father> <mother> <sex> [<affected>] 
  ##                  <genotype_1> ... <genotype_n>
  ##
  ## some pedigree files contain <affected> after <sex> and before
  ## <genotype_1>, some pedigree files do not.
  ##
  ## <family> is a unique identifier for each family, and within each family
  ## <pid> is a unique identifier for an individual.
  ## <father> and <mother> identify the individuals father and mother
  ##    (if this line refers to a founder, these should be set to
  ##     zero).
  ##  <sex> denotes the individuals sex, using the convention
  ##     1=male, 2=female.
  ##
  ## Each <genotype> is encoded as two integer allele numbers.

  filename=as.character(filename)

  len <- length(columns)

  ## read numer of rows, columns and markers
  res <- .C(
            "getDimOfFile", 
            filename=filename, 
            nrow=as.integer(0), 
            sampleInfoLen=as.integer(len), 
            nmarker=as.integer(0), 
            errorFlag=as.integer(0),
            PACKAGE="GeneticsBase"             
            )

  errorFlag=res$errorFlag
  if(errorFlag!=0)
    stop("Unable to determine file dimensions for ped file `", filename, "'.")

  nrow=res$nrow
  if(nrow==0)
    stop("No data in ped file `", filename, "'.")

  nmarker=res$nmarker
  if(nmarker==0)
    stop("No marker information in ped file `", filename, "'.")

  if(quiet==FALSE)
    cat("Reading", nmarker, "markers and", nrow,
        "subjects from `", filename, "' ...\n") 

  ncol <- 2*nmarker+length(columns)

  ped <- rep(0, nrow*ncol)
  strSpace <- paste(rep(" ", 60), collapse='')
  markerNames <- rep(strSpace, nmarker)

  res.getPed <- .C(
                   "getPed", 
                   filename=filename, 
                   ped=as.integer(ped), 
                   nrow=as.integer(nrow), 
                   ncol=as.integer(ncol), 
                   nmarker=as.integer(nmarker), 
                   markerNames=as.character(markerNames), 
                   errorFlag=as.integer(0),
                   PACKAGE="GeneticsBase"             
                   )

  errorFlag=res.getPed$errorFlag
  if(errorFlag!=0)
    stop("Unable to load data from `", filename, "'")

  ped <- res.getPed$ped
  ped <- matrix(ped, nrow=nrow, byrow=T)
  markerNames <- res.getPed$markerNames
  nmarker <- length(markerNames)

  markercols <- c(
                  sapply(markerNames, 
                         function(x) paste(x, c("1", "2"), sep=".")
                         )
                  )
  ## Add these to the other columns
  colNames <- c(columns, markercols)

  ped <- matrix(ped, nrow=nrow, ncol=ncol) 
  colnames(ped) <- colNames
  rownames(ped) <- paste(ped[, 1], ped[, 2], sep=".")

  ## we can do checking in analysis
  #tmp <- checkColumn(ped, columns)


  ## obtain unique nuclear family id
  family <- as.vector(ped[, 1])
  family.u <- unique(family)

  ## obtain sizes (number of members) of nuclear families
  familySize <- tapply(family, family, length)

  ## obtain the number of nuclear families
  nFamily <- length(family.u)

 if(!quiet)
    cat("generating 'geneSet' object...\n")

  Position<-rep("?", length(markerNames))
  pedObj<-list(ped=ped, columns=columns, markerNames=markerNames, Position, fileName=filename)
  
  cs <- ped2geneSet(pedObj, quiet)

  missingCodes <- lapply(cs@transTables,
                         function(...) as.character(missingval))

  cs@missingCodes <- missingCodes
  cs@notes <- paste("Loaded from file `", filename, "'.", sep='')
  cs@phase <- phase

  if(!quiet)
  { 
    cat("Successfully read the pedigree file `", filename, "'.\n");
    cat("\n")
    cat("Number of Markers: ", length(markerNames), "\n")
    cat("Number of Subjects:", nrow(ped), "\n")
    cat("Number of Families:", nFamily, "\n")
    cat("\n")
  }

  cs
}

## Variants
readGenes.hapmap.ped <- function(filename, ... )
  readGenes.ped(
                filename=filename, 
                columns=c("family", "pid", "father", "mother",
                          "sex", "affected"), 
                ...
                )

readGenes.pbat.ped <- readGenes.hapmap.ped
readGenes.fbat.ped <- readGenes.hapmap.ped
